@@ -273,23 +273,24 @@ class resonance_lines(object):
             plt.figure(fig.number)
         else:
             fig = plt.figure()
+        ax = fig.add_subplot(1, 1, 1)  # create an axes object in the figure
         Qx_min = self.Qx_min
         Qx_max = self.Qx_max
         Qy_min = self.Qy_min
         Qy_max = self.Qy_max 
-        plt.xlim(Qx_min, Qx_max)
-        plt.ylim(Qy_min, Qy_max)
-        plt.xlabel('$\mathrm{Q_x}$' , fontsize='large')
-        plt.ylabel('$\mathrm{Q_y}$', fontsize='large')        
+        ax.set_xlabel('$\mathrm{Q_x}$')
+        ax.set_ylabel('$\mathrm{Q_y}$')        
+        ax.set_xlim(Qx_min, Qx_max)
+        ax.set_ylim(Qy_min, Qy_max)
         for resonance in self.resonance_list:
             nx = resonance[0]
             ny = resonance[1]
             for res_sum in resonance[2]:        
                 if ny:
-                    line, = plt.plot([Qx_min, Qx_max], \
+                    line, = ax.plot([Qx_min, Qx_max], \
                         [(res_sum-nx*Qx_min)/ny, (res_sum-nx*Qx_max)/ny])
                 else:
-                    line, = plt.plot([np.float(res_sum)/nx, np.float(res_sum)/nx],[Qy_min, Qy_max])
+                    line, = ax.plot([np.float(res_sum)/nx, np.float(res_sum)/nx],[Qy_min, Qy_max])
                 if ny%2:
                     plt.setp(line, linestyle='--', zorder=1) # for skew resonances
                 if res_sum%self.periodicity:
@@ -298,7 +299,7 @@ class resonance_lines(object):
                     plt.setp(line, color='r', zorder=1, linewidth=2.0) # systematic resonances
         if(interactive):
             plt.draw()
-        return fig
+        return ax
     
     def plot_resonance_and_tune_footprint(self, tracker, Q_work_int = None, figure_object = None, interactive=False):    
         """
